# IncidentSearchResponseWrapper

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**data** | [**list[IncidentWrapper]**](IncidentWrapper.md) | in: body | [optional] 
**not_updated** | **int** |  | [optional] 
**total** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


